@@ -44,20 +44,20 @@ class DAVProvider:
             # no namespace
             return key
 
-        ns_id = ns_map.setdefault(ns, "ns{}".format(len(ns_map) + 1))
-        return "{}:{}".format(ns_id, key)
+        ns_id = ns_map.setdefault(ns, f"ns{len(ns_map) + 1}")
+        return f"{ns_id}:{key}"
 
     @staticmethod
     def _create_data_lock_discovery(lock_info: DAVLockInfo) -> dict:
         return {
             "D:activelock": {
                 "D:locktype": {"D:write": None},
-                "D:lockscope": {"D:{}".format(lock_info.lock_scope.name): None},
+                "D:lockscope": {f"D:{lock_info.lock_scope.name}": None},
                 "D:depth": lock_info.depth.value,
                 "D:owner": lock_info.owner,
-                "D:timeout": "Second-{}".format(lock_info.timeout),
+                "D:timeout": f"Second-{lock_info.timeout}",
                 "D:locktoken": {
-                    "D:href": "opaquelocktoken:{}".format(lock_info.token),
+                    "D:href": f"opaquelocktoken:{lock_info.token}",
                 },
             },
         }
@@ -96,11 +96,52 @@ class DAVProvider:
     
        404 Not Found - The property does not exist.
     
-    https://tools.ietf.org/html/rfc4918#page-78
+    https://www.rfc-editor.org/rfc/rfc4918#section-11
+    11.  Status Code Extensions to HTTP/1.1
+    
+       The following status codes are added to those defined in HTTP/1.1
+       [RFC2616].
+    
     11.1.  207 Multi-Status
     
        The 207 (Multi-Status) status code provides status for multiple
        independent operations (see Section 13 for more information).
+    
+    11.2.  422 Unprocessable Entity
+    
+       The 422 (Unprocessable Entity) status code means the server
+       understands the content type of the request entity (hence a
+       415(Unsupported Media Type) status code is inappropriate), and the
+       syntax of the request entity is correct (thus a 400 (Bad Request)
+       status code is inappropriate) but was unable to process the contained
+       instructions.  For example, this error condition may occur if an XML
+       request body contains well-formed (i.e., syntactically correct), but
+       semantically erroneous, XML instructions.
+    
+    11.3.  423 Locked
+    
+       The 423 (Locked) status code means the source or destination resource
+       of a method is locked.  This response SHOULD contain an appropriate
+       precondition or postcondition code, such as 'lock-token-submitted' or
+       'no-conflicting-lock'.
+       
+   11.4.  424 Failed Dependency
+
+       The 424 (Failed Dependency) status code means that the method could
+       not be performed on the resource because the requested action
+       depended on another action and that action failed.  For example, if a
+       command in a PROPPATCH method fails, then, at minimum, the rest of
+       the commands will also fail with 424 (Failed Dependency).
+    
+    11.5.  507 Insufficient Storage
+    
+       The 507 (Insufficient Storage) status code means the method could not
+       be performed on the resource because the server is unable to store
+       the representation needed to successfully complete the request.  This
+       condition is considered to be temporary.  If the request that
+       received this status code was the result of a user action, the
+       request MUST NOT be repeated until it is requested by a separate user
+       action.
     """
 
     async def do_propfind(self, request: DAVRequest) -> dict[DAVPath, DAVProperty]:
@@ -192,7 +233,7 @@ class DAVProvider:
             # namespace
             # TODO ns0 => DAV:
             for k, v in ns_map.items():
-                response_item["@xmlns:{}".format(v)] = k
+                response_item[f"@xmlns:{v}"] = k
 
             response.append(response_item)
 
@@ -267,7 +308,7 @@ class DAVProvider:
         data = dict()
         for ns, key in sucess_ids:
             # data['ns1:{}'.format(item)] = None
-            data["D:{}".format(key)] = None  # TODO namespace
+            data[f"D:{key}"] = None  # TODO namespace
 
         data = {
             "D:multistatus": {
@@ -780,7 +821,7 @@ class DAVProvider:
 
         message = self._create_lock_response(lock_info)
         headers = {
-            b"Lock-Token": "opaquelocktoken:{}".format(lock_info.token).encode("utf-8"),
+            b"Lock-Token": f"opaquelocktoken:{lock_info.token}".encode("utf-8"),
         }
         response = DAVResponse(
             status=200,
